@@ -211,7 +211,9 @@ typedef enum
   G_DESKTOP_STYLUS_BUTTON_ACTION_MIDDLE,
   G_DESKTOP_STYLUS_BUTTON_ACTION_RIGHT,
   G_DESKTOP_STYLUS_BUTTON_ACTION_BACK,
-  G_DESKTOP_STYLUS_BUTTON_ACTION_FORWARD
+  G_DESKTOP_STYLUS_BUTTON_ACTION_FORWARD,
+  G_DESKTOP_STYLUS_BUTTON_ACTION_SWITCH_MONITOR,
+  G_DESKTOP_STYLUS_BUTTON_ACTION_KEYBINDING
 } GDesktopStylusButtonAction;
 
 typedef enum
@@ -251,4 +253,39 @@ typedef enum
   G_DESKTOP_FONT_RGBA_ORDER_VBGR,
 } GDesktopFontRgbaOrder;
 
+typedef enum
+{
+  G_DESKTOP_COLOR_SCHEME_DEFAULT,
+  G_DESKTOP_COLOR_SCHEME_PREFER_DARK,
+  G_DESKTOP_COLOR_SCHEME_PREFER_LIGHT,
+} GDesktopColorScheme;
+
+typedef enum
+{
+  G_DESKTOP_POINTING_STICK_SCROLL_METHOD_DEFAULT,
+  G_DESKTOP_POINTING_STICK_SCROLL_METHOD_NONE,
+  G_DESKTOP_POINTING_STICK_SCROLL_METHOD_ON_BUTTON_DOWN
+} GDesktopPointingStickScrollMethod;
+
+typedef enum
+{
+  G_DESKTOP_FONT_RENDERING_AUTOMATIC,
+  G_DESKTOP_FONT_RENDERING_MANUAL,
+} GDesktopFontRendering;
+
+typedef enum
+{
+  G_DESKTOP_ACCENT_COLOR_BLUE,
+  G_DESKTOP_ACCENT_COLOR_TEAL,
+  G_DESKTOP_ACCENT_COLOR_GREEN,
+  G_DESKTOP_ACCENT_COLOR_YELLOW,
+  G_DESKTOP_ACCENT_COLOR_ORANGE,
+  G_DESKTOP_ACCENT_COLOR_RED,
+  G_DESKTOP_ACCENT_COLOR_PINK,
+  G_DESKTOP_ACCENT_COLOR_PURPLE,
+  G_DESKTOP_ACCENT_COLOR_SLATE,
+
+  G_DESKTOP_ACCENT_COLOR_MAIA = G_DESKTOP_ACCENT_COLOR_SLATE + 100,
+} GDesktopAccentColor;
+
 #endif /* __gdesktop_enums_h__ */
